# About
<p>This application is a hangman game for terminal.</p>

# Install
<b>Via pip</b><br>
pip3 install hangmangame

<b>Via github</b><br>
git clone https://github.com/jeffrichardchemistry/hangmangame

cd hangmangame

python3 setup.py install

# Run
<b>In a terminal</b>

python3 -m hangmangame

<b>As a module</b><br>
from hangmangame import hangman

get_game = hangman()

get_game.runHangman()
